@@ -30,17 +30,17 @@ class FirstOfNodeFactory : public AbstractNodeFactory
 public:
   FirstOfNodeFactory();
 
-  Node* getNode( const QString &tagContent, Parser *p ) const;
-
+  Node *getNode(const QString &tagContent, Parser *p) const override;
 };
 
 class FirstOfNode : public Node
 {
   Q_OBJECT
 public:
-  explicit FirstOfNode( QList<FilterExpression> list, QObject *parent = 0 );
+  explicit FirstOfNode(const QList<FilterExpression> &list,
+                       QObject *parent = 0);
 
-  void render( OutputStream *stream, Context *c ) const;
+  void render(OutputStream *stream, Context *c) const override;
 
 private:
   QList<FilterExpression> m_variableList;
