@@ -31,25 +31,25 @@ class WidthRatioNodeFactory : public AbstractNodeFactory
 public:
   WidthRatioNodeFactory();
 
-  Node* getNode( const QString &tagContent, Parser *p ) const;
-
+  Node *getNode(const QString &tagContent, Parser *p) const override;
 };
 
 class WidthRatioNode : public Node
 {
   Q_OBJECT
 public:
-  WidthRatioNode( FilterExpression valExpr, FilterExpression maxExpr, FilterExpression maxWidth, QObject *parent = 0 );
+  WidthRatioNode(const FilterExpression &valExpr,
+                 const FilterExpression &maxExpr,
+                 const FilterExpression &maxWidth, QObject *parent = 0);
 
-  void render( OutputStream *stream, Context *c ) const;
+  void render(OutputStream *stream, Context *c) const override;
 
 private:
-  static int round( qreal );
+  static int round(qreal);
 
   FilterExpression m_valExpr;
   FilterExpression m_maxExpr;
   FilterExpression m_maxWidth;
-
 };
 
 #endif
