@@ -22,7 +22,7 @@
 #define GRANTLEE_UTIL_P_H
 
 #include "context.h"
-#include "grantlee_core_export.h"
+#include "grantlee_templates_export.h"
 #include "safestring.h"
 
 #include <QtCore/QVariant>
@@ -37,62 +37,63 @@ namespace Grantlee
 
   @see @ref truthiness
 */
-GRANTLEE_CORE_EXPORT bool variantIsTrue( const QVariant &variant );
-
-/**
-  @deprecated Use MetaType::toVariantList instead.
-  Converts the @p variant into a list.
-*/
-GRANTLEE_CORE_EXPORT QVariantList variantToList( const QVariant &variant );
+GRANTLEE_TEMPLATES_EXPORT bool variantIsTrue(const QVariant &variant);
 
 /**
   Converts the @p input into its unescaped form.
 
-  Double slashes are converted to single slashes, \\&quot is converted to &quot etc.
+  Double slashes are converted to single slashes, \\&quot is converted to &quot
+  etc.
 */
-GRANTLEE_CORE_EXPORT QString unescapeStringLiteral( const QString &input );
+GRANTLEE_TEMPLATES_EXPORT QString unescapeStringLiteral(const QString &input);
 
 /**
   Marks the @p input as safe.
 */
-GRANTLEE_CORE_EXPORT Grantlee::SafeString markSafe( const Grantlee::SafeString &input );
+GRANTLEE_TEMPLATES_EXPORT Grantlee::SafeString
+markSafe(const Grantlee::SafeString &input);
 
 /**
   Marks the @p input as requiring escaping.
 */
-GRANTLEE_CORE_EXPORT Grantlee::SafeString markForEscaping( const Grantlee::SafeString &input );
+GRANTLEE_TEMPLATES_EXPORT Grantlee::SafeString
+markForEscaping(const Grantlee::SafeString &input);
 
 /**
   Retrieves and returns a SafeString from the @p input.
 */
-GRANTLEE_CORE_EXPORT Grantlee::SafeString getSafeString( const QVariant &input );
+GRANTLEE_TEMPLATES_EXPORT Grantlee::SafeString
+getSafeString(const QVariant &input);
 
 /**
   Returns whether @p input contains a SafeString.
 */
-GRANTLEE_CORE_EXPORT bool isSafeString( const QVariant &input );
+GRANTLEE_TEMPLATES_EXPORT bool isSafeString(const QVariant &input);
 
 /**
-  Returns true if the type of @p input can be inserted into a rendered template directly.
+  Returns true if the type of @p input can be inserted into a rendered template
+  directly.
   Not that lists, hashes and QObject*s can not be.
 */
-GRANTLEE_CORE_EXPORT bool supportedOutputType( const QVariant &input );
+GRANTLEE_TEMPLATES_EXPORT bool supportedOutputType(const QVariant &input);
 
 /**
-  Compares @p lhs and @p rhs for equality. SafeStrings are compared as raw QStrings. Their safeness is not part of the comparison.
+  Compares @p lhs and @p rhs for equality. SafeStrings are compared as raw
+  QStrings. Their safeness is not part of the comparison.
 
   @see QVariant::operator==
 */
-GRANTLEE_CORE_EXPORT bool equals( const QVariant &lhs, const QVariant &rhs );
+GRANTLEE_TEMPLATES_EXPORT bool equals(const QVariant &lhs, const QVariant &rhs);
 
 #ifndef Q_QDOC
 /**
   @internal
-  Returns the @p list as a formatted string. This is for debugging purposes only.
+  Returns the @p list as a formatted string. This is for debugging purposes
+  only.
 */
-GRANTLEE_CORE_EXPORT Grantlee::SafeString toString( const QVariantList &list );
+GRANTLEE_TEMPLATES_EXPORT Grantlee::SafeString
+toString(const QVariantList &list);
 #endif
-
 }
 
 #endif
