@@ -30,26 +30,24 @@ class QScriptContext;
 
 using namespace Grantlee;
 
-QScriptValue markSafeFunction( QScriptContext *context,
-                               QScriptEngine *engine );
+QScriptValue markSafeFunction(QScriptContext *context, QScriptEngine *engine);
 
 class ScriptableSafeString : public QObject
 {
   Q_OBJECT
 public:
-  ScriptableSafeString( QObject* parent = 0 );
+  ScriptableSafeString(QObject *parent = 0);
 
-  void setContent( const SafeString &content );
+  void setContent(const SafeString &content);
   SafeString wrappedString() const;
 
 public Q_SLOTS:
   bool isSafe() const;
-  void setSafety( bool safeness );
+  void setSafety(bool safeness);
   QString rawString();
 
 private:
   SafeString m_safeString;
 };
 
-
 #endif
